# == Class: multipathd
class multipathd (
  $service_name        = $multipathd::params::service_name,
  $service_ensure      = $multipathd::params::service_ensure,
  $service_enable      = $multipathd::params::service_enable,
  $service_package     = $multipathd::params::service_package,
  $package_ensure      = $multipathd::params::package_ensure,
  $service_configfile  = $multipathd::params::service_configfile,
  $polling_interval    = $multipathd::params::polling_interval,
  $find_multipaths     = $multipathd::params::find_multipaths,
  $reassign_maps       = $multipathd::params::reassign_maps,
  $path_selector       = $multipathd::params::path_selector,
  $failback            = $multipathd::params::failback,
  $user_friendly_names = $multipathd::params::user_friendly_names,
  $flush_on_last_del   = $multipathd::params::flush_on_last_del,
  $detect_prio         = $multipathd::params::detect_prio,
  $fast_io_fail_tmo    = $multipathd::params::fast_io_fail_tmo,
  $no_path_retry       = $multipathd::params::no_path_retry,
  $dev_loss_tmo        = $multipathd::params::dev_loss_tmo,
  $max_fds             = $multipathd::params::max_fds,
  $device_all_devs     = $multipathd::params::device_all_devs,
  $bindings_file       = $multipathd::params::bindings_file,
  $paths               = $multipathd::params::paths,
  $blacklist           = $multipathd::params::blacklist,
) inherits multipathd::params {

  validate_string($service_name)
  validate_string($service_ensure)
  validate_bool($service_enable)
  validate_string($service_package)
  validate_string($package_ensure)
  validate_absolute_path($service_configfile)
  validate_integer($polling_interval)
  validate_string($find_multipaths)
  validate_string($reassign_maps)
  validate_string($path_selector)
  validate_string($failback)
  validate_string($user_friendly_names)
  validate_string($flush_on_last_del)
  validate_string($detect_prio)
  validate_integer($fast_io_fail_tmo)
  validate_string($no_path_retry)
  validate_integer($dev_loss_tmo)
  validate_integer($max_fds)
  validate_absolute_path($bindings_file)

  if $aliases {
    validate_array($aliases)
  }

  package {$service_package:
    ensure => $package_ensure,
  }

  service { $service_name:
    ensure  => $service_ensure,
    enable  => $service_enable,
    require => Package[$service_package],
  }

  file {$service_configfile:
    ensure  => 'present',
    owner   => 'root',
    group   => 'root',
    mode    => '0600',
    content => template('multipathd/etc/multipath.conf.erb'),
    require => Package[$service_package],
    notify  => Service[$service_name],
  }

}
